#[unsafe(no_mangle)]pub extern "C" fn vldb_sqlite_custom_word_list_len(
handle: *mut VldbSqliteCustomWordListHandle,
) -> u64Expand description
返回自定义词列表长度。 Return the number of custom words in the list.
#[unsafe(no_mangle)]pub extern "C" fn vldb_sqlite_custom_word_list_len(
handle: *mut VldbSqliteCustomWordListHandle,
) -> u64返回自定义词列表长度。 Return the number of custom words in the list.