Module sql_exec

Module sql_exec 

Structs

ChunkCollector
Arrow IPC chunk 收集器。 Arrow IPC chunk collector.
ExecuteBatchResult
通用批量执行结果。 Shared batch-execution result.
ExecuteScriptResult
通用 SQL 执行结果。 Shared SQL execution result.
QueryJsonResult
JSON 查询结果。 JSON query result.
QueryStreamMetrics
QueryStream 执行过程中的共享统计信息。 Shared metrics produced during QueryStream execution.
QueryStreamResult
Arrow IPC chunk 查询结果。 Arrow IPC chunk query result.
TempFileChunkWriter
基于临时文件的 QueryStream chunk 写入器。 Temporary-file-backed QueryStream chunk writer.

Enums

SqlExecCoreError
通用 SQL 核心错误。 Shared SQL core error.

Constants

DEFAULT_IPC_CHUNK_BYTES
默认 Arrow IPC chunk 大小,供流式查询在内存与下游消费之间折中。 Default Arrow IPC chunk size used to balance memory and downstream consumption.
STREAMING_BATCH_ROWS
单批次物化的最大行数,避免单个 Arrow record batch 过大。 Maximum number of rows materialized per batch to avoid oversized Arrow record batches.

Traits

QueryStreamChunkWriter
Arrow IPC chunk 收集器。 Arrow IPC chunk collector.

Functions

count_sql_statements
统计 SQL 中实际包含的有效语句数量。 Count the number of effective SQL statements contained in the input string.
execute_batch
执行同 SQL 多组参数的批量执行。 Execute a single SQL statement repeatedly with multiple parameter groups.
execute_script
执行脚本或单条语句。 Execute a script or a single statement.
has_multiple_sql_statements
检测 SQL 是否包含多条语句。 Detect whether the SQL string contains multiple statements.
json_param_to_sqlite_value
解析 JSON 标量到 SQLite 值。 Convert a JSON scalar into a SQLite value.
parse_batch_params
从 gRPC 批量参数中解析最终批量 SQLite 参数列表。 Parse the final batch SQLite parameter list from gRPC batch params.
parse_legacy_params_json
从 legacy params_json 字符串解析参数列表。 Parse parameter list from the legacy params_json string.
parse_request_params
从 gRPC typed params 与 params_json 中解析最终的 SQLite 参数列表。 Parse the final SQLite parameter list from gRPC typed params and params_json.
proto_param_to_sqlite_value
解析 typed 单值到 SQLite 值。 Convert a typed protobuf value to a SQLite value.
query_json
执行查询并返回 JSON 行集。 Execute a query and return a JSON row set.
query_stream
执行查询并返回 Arrow IPC chunk 列表。 Execute a query and return Arrow IPC chunks.
query_stream_with_writer
执行查询并把 Arrow IPC chunk 写入任意 Write 接口。 Execute a query and write Arrow IPC chunks into any Write sink.
sqlite_value_to_json
把 SQLite 值转换为 JSON 值。 Convert a SQLite value to a JSON value.