pub fn list_custom_words(
connection: &Connection,
) -> Result<ListCustomWordsResult>Expand description
列出当前启用的自定义词(中英双语)。 List enabled custom words with a structured result payload (bilingual).
pub fn list_custom_words(
connection: &Connection,
) -> Result<ListCustomWordsResult>列出当前启用的自定义词(中英双语)。 List enabled custom words with a structured result payload (bilingual).